Forms › Form Validation — Stisla

# Form Validation

Form validation using default from Bootstrap 4

#### Default Validation

Your Name
Email
Subject
Message

#### JavaScript Validation

Your Name
What's your name?
Email
Oh no! Email is invalid.
Subject
Good job!
Message
What do you wanna say?

#### Server-side Validation

Your Name
Good job!
Email
Oh no! Email is invalid.
Subject
Message Hello, i'm handsome!
Oh no! You entered an inappropriate word.

#### JavaScript Validation (Horizontal Form)

Your Name
What's your name?
Email
Oh no! Email is invalid.
Subject
Good job!
Message
What do you wanna say?